# -*- coding: utf-8 -*-

"""
status_cog
~~~~~~~~~~

A discord.py extension that enables status reports to a support server.

:copyright: (c) 2022 Pjay
:license: MIT, see LICENSE for more details

"""

from status_cog.cog import *

__all__ = (
    "StatusCog",
    "setup"
)
